#!/usr/bin/python3

"""Save an FSDB file to an apache parquet file"""

import pyfsdb
from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter, FileType
import sys
import logging

def parse_args():
    parser = ArgumentParser(formatter_class=ArgumentDefaultsHelpFormatter,
                            description=__doc__,
                            epilog="Exmaple Usage: fsdb2parquet -c col1 col2 -- file.fsdb file.parquet ")

    parser.add_argument("-c", "--categories", nargs="*",
                        type=str, help="Columns to declare as categories")

    parser.add_argument("-C", "--compression-type", default="GZIP", type=str,
                        help="The compression type to use (SNAPPY or GZIP)")

    parser.add_argument("-l", "--compression-level", default=None, type=int,
                        help="The compression level to pass to the algorithm")

    parser.add_argument("-o", "--row-offsets", default=50000000, type=int,
                        help="Row size to write")

    parser.add_argument("-f", "--fast-read", action="store_true",
                        help="If the dataset does not contain # characters, this can be used")

    parser.add_argument("input_file", type=FileType('r'),
                        help="The input fsdb file to load (can be - for stdin)")

    parser.add_argument("output_file", type=str,
                        help="The output parquet file to write")

    args = parser.parse_args()
    return args


def main():
    args = parse_args()

    try:
        import pyarrow.parquet
    except Exception:
        error("Failed to load the pyarrow python module: use 'pip install pyarrow' to install it.")
        exit()

    fh = pyfsdb.Fsdb(file_handle=args.input_file)

    df = fh.get_pandas(data_has_comment_chars=(not args.fast_read))

    if args.categories:
        for column in args.categories:
            df[column] = df[column].astype('category')

    table = pyarrow.Table.from_pandas(df)
    pyarrow.parquet.write_table(table, args.output_file,
                                compression=args.compression_type,
                                compression_level=args.compression_level)


if __name__ == "__main__":
    main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="pyfsdb_parquet",
    version="1.0",
    author="Wes Hardaker",
    author_email="opensource@hardakers.net",
    description="Python tools to convert to and from FSDB and parquet files",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/gawseed/pyfsdb_parquet",
    packages=setuptools.find_packages(),
    entry_points={
        "console_scripts": [
            "pdb2parquet = pyfsdb_parquet.tools.fsdb2parquet:main",
            "parquet2pdb = pyfsdb_parquet.tools.parquet2fsdb:main",
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'pyfsdb>=2.0.2',
        'cramjam', # fails to auto install?
        'pandas',
        'fastparquet',
        'pyarrow'
    ],
    python_requires=">=3.6",
    test_suite="nose.collector",
    tests_require=["nose"],
)



#!/usr/bin/python3

"""Load a parquet file and convert it to FSDB, with an optional column
and filter list"""

import pyfsdb

from argparse import ArgumentParser, ArgumentDefaultsHelpFormatter, FileType
import sys


def parse_args():
    parser = ArgumentParser(formatter_class=ArgumentDefaultsHelpFormatter,
                            description=__doc__,
                            epilog="Exmaple Usage: parque2fsdb -c col1 col2 -- file.parquet file.fsdb")

    parser.add_argument("-c", "--columns", nargs="*",
                        type=str, help="Columns to load")

    parser.add_argument("-f", "--filters", nargs="*",
                        type=str, help="Filters to apply to the data [format tbd]")

    parser.add_argument("-l", "--line-by-line", action="store_true",
                        help="Read the parquet file line by line instead of all at once (slower)")

    parser.add_argument("input_file", type=str,
                        help="The input parquet file to load")

    parser.add_argument("output_file", type=FileType('w'),
                        nargs='?', default=sys.stdout,
                        help="The output FSDB file")

    args = parser.parse_args()
    return args


def main():
    args = parse_args()

    try:
        import fastparquet
    except Exception:
        error("Failed to load the fastparquet python module: use 'pip install fastparquet' to install it.")
        exit()

    fh = pyfsdb.Fsdb(out_file_handle=args.output_file)
    pf = fastparquet.ParquetFile(args.input_file)

    if args.line_by_line:
        for df in pf.iter_row_groups(columns=args.columns):
            fh.put_pandas(df)
    else:
        df = pf.to_pandas(columns=args.columns)
        fh.put_pandas(df)


if __name__ == "__main__":
    main()
